# Readme Page

A script to create a readme [GitHub Page](https://help.github.com/articles/creating-project-pages-manually) for your project. See an [example](http://fernandojunior.github.io/readme-page).

This project uses [BeautifulSoup](http://www.crummy.com/software/BeautifulSoup/), [mkdocs](http://mkdocs.github.io/mkdocs-bootstrap/) and [six](https://pythonhosted.org/six/).


## Installation & Usage

1. Run `pip install readme-page` to install the script.

2. Run `readme-page` to create your repository GitHub Page.

3. Checkout the repository page at `http://<your_github_username>.github.io/<repository_name>`

## Contributing

See [CONTRIBUTING](https://github.com/fernandojunior/readme-page/CONTRIBUTING.md).

## License

[![CC0](https://i.creativecommons.org/l/by-nc-sa/4.0/88x31.png)](https://creativecommons.org/licenses/by-nc-sa/4.0/)

The MIT License.

-

Copyright (c) 2016 [Fernando Felix do Nascimento Junior](https://github.com/fernandojunior/).
